@@ -779,9 +779,10 @@ TLS_APPL_STATE *tls_client_init(const TLS_CLIENT_INIT_PROPS *props)
     /*
      * With OpenSSL 1.0.2 and later the client EECDH curve list becomes
      * configurable with the preferred curve negotiated via the supported
-     * curves extension.
+     * curves extension.  With OpenSSL 3.0 and TLS 1.3, the same applies
+     * to the FFDHE groups which become part of a unified "groups" list.
      */
-    tls_auto_eecdh_curves(client_ctx, var_tls_eecdh_auto);
+    tls_auto_groups(client_ctx, var_tls_eecdh_auto, var_tls_ffdhe_auto);
 
     /*
      * Finally, the setup for the server certificate checking, done "by the
